==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The tag key.
 * @property value The tag value.
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs(
    public val key: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs> {
    override fun toJava():
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs].
 */
@PulumiTagMarker
public class
ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgsBuilder
internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The tag key.
     */
    @JvmName("vkvputhurytnjdkg")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The tag value.
     */
    @JvmName("dxcwrijrniahipig")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The tag key.
     */
    @JvmName("oxrrilnospcxcjnb")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The tag value.
     */
    @JvmName("ooeokudpujsxykpf")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build():
        ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs =
        ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs(
            key = key,
            `value` = `value`,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The tag key.
 * @property value The tag value.
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs(
    public val key: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs> {
    override fun toJava(): com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs].
 */
@PulumiTagMarker
public class
ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgsBuilder
internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The tag key.
     */
    @JvmName("xbkhsqcimiuxpspw")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The tag value.
     */
    @JvmName("wxwmevxpwnvxigni")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The tag key.
     */
    @JvmName("alkeiaaeheubnein")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The tag value.
     */
    @JvmName("kiwmwanqyctujmli")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs =
        ClassificationJobS3JobDefinitionBucketCriteriaExcludesAndTagCriterionTagValueArgs(
            key = key,
            `value` = `value`,
        )
}
